import { type FastifyPluginAsync } from 'fastify';
import fsp from 'node:fs/promises';

import { Config, config } from '../config.js';
import { InvalidAuthorization } from '../errors.js';
import { getFilesFor, getPathFor } from '../store.js';

export default (async function (fastify) {
    fastify.delete('/:name', async (req) => {
        const key = req.headers.authorization?.replace('Bearer ', '') ?? 'none';

        const client = Config.getClientByKey(config, key);
        if (!client) {
            throw InvalidAuthorization();
        }

        const params = req.params as { name: string };
        const files = await getFilesFor(client.name);

        if (!files.find((x) => x === client.name + '-' + params.name)) {
            return { status: 'ok' };
        }

        await fsp.rm(getPathFor(params.name, client.name));

        return { status: 'ok' };
    });
} as FastifyPluginAsync);
