import { type FastifyPluginAsync } from 'fastify';
import fsp from 'node:fs/promises';
import path from 'node:path';
import { Stats } from 'node:fs';

import { Config, config } from '../config.js';
import { InvalidAuthorization } from '../errors.js';

type ListFilesResponse = {
    name: string;
    created: Date;
};

export default (async function (fastify) {
    fastify.get('/list', async (req) => {
        const key = req.headers.authorization?.replace('Bearer ', '') ?? 'none';

        const client = Config.getClientByKey(config, key);
        if (!client) {
            throw InvalidAuthorization();
        }

        const rawfl = await fsp.readdir(config.storePath);
        const files: [Stats, string][] = await Promise.all(
            rawfl
                .filter((x) => x.startsWith(client.name + '-'))
                .map(async (x) => [
                    await fsp.stat(path.join(config.storePath, x)),
                    x,
                ]),
        );

        return files.map(
            (x) =>
                ({
                    name: x[1].replace(client.name + '-', ''),
                    created: x[0].birthtime,
                }) as ListFilesResponse,
        );
    });
} as FastifyPluginAsync);
